==> react-collapsible-composed-1.5.0.tgz: package/lib/index.js <==
import _inheritsLoose from "@babel/runtime/helpers/esm/inheritsLoose";
import React, { Component } from 'react';
import PropTypes from 'prop-types';
import cx from 'classnames';

var CollapsibleComposed =
/*#__PURE__*/
function (_Component) {
  _inheritsLoose(CollapsibleComposed, _Component);

  function CollapsibleComposed() {
    var _this;

    for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    _this = _Component.call.apply(_Component, [this].concat(args)) || this;
    _this.state = {
      collapsed: _this.props.collapsed
    };
    return _this;
  }

  var _proto = CollapsibleComposed.prototype;

  _proto._toggle = function _toggle() {
    var collapsed = this.state.collapsed;
    this.setState({
      collapsed: !collapsed
    });
    this.props.onToggle(!collapsed);
  };

  _proto.render = function render() {
    var _this2 = this;

    var _this$props = this.props,
        hiddenItems = _this$props.hiddenItems,
        inline = _this$props.inline,
        items = _this$props.items,
        label = _this$props.label;
    var collapsed = this.state.collapsed;
    var collapseIcon = collapsed ? '+' : '-';
    var itemClass = cx('sui-CollapsibleComposed-item', {
      'sui-CollapsibleComposed-item--inline': inline
    });
    var togglerClass = cx('sui-CollapsibleComposed-toggler', {
      'sui-CollapsibleComposed-item--inline': inline
    });
    var itemsToToggle = !collapsed && hiddenItems || [];
    var totalItems = items.concat(itemsToToggle);
    var displayItems = totalItems.map(function (item, index) {
      return React.createElement("div", {
        className: itemClass,
        key: index
      }, item);
    });
    return React.createElement("div", {
      className: "sui-CollapsibleComposed"
    }, React.createElement("div", {
      className: "sui-CollapsibleComposed-label"
    }, label), React.createElement("div", {
      className: "sui-CollapsibleComposed-content"
    }, displayItems, hiddenItems.length > 0 && React.createElement("div", {
      className: togglerClass,
      onClick: function onClick() {
        return _this2._toggle();
      }
    }, collapseIcon)));
  };

  return CollapsibleComposed;
}(Component);

CollapsibleComposed.displayName = 'CollapsibleComposed';
CollapsibleComposed.defaultProps = {
  collapsed: true,
  hiddenItems: [],
  inline: false,
  items: [],
  onToggle: function onToggle() {}
};
export default CollapsibleComposed;

==> react-collapsible-composed-1.6.0.tgz: package/lib/index.js <==
import _inheritsLoose from "@babel/runtime/helpers/esm/inheritsLoose";
import { jsxs as _jsxs } from "react/jsx-runtime";
import { jsx as _jsx } from "react/jsx-runtime";
import { Component } from 'react';
import cx from 'classnames';

var CollapsibleComposed = /*#__PURE__*/function (_Component) {
  _inheritsLoose(CollapsibleComposed, _Component);

  function CollapsibleComposed() {
    var _this;

    for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    _this = _Component.call.apply(_Component, [this].concat(args)) || this;
    _this.state = {
      collapsed: _this.props.collapsed
    };
    return _this;
  }

  var _proto = CollapsibleComposed.prototype;

  _proto._toggle = function _toggle() {
    var collapsed = this.state.collapsed;
    this.setState({
      collapsed: !collapsed
    });
    this.props.onToggle(!collapsed);
  };

  _proto.render = function render() {
    var _this2 = this;

    var _this$props = this.props,
        hiddenItems = _this$props.hiddenItems,
        inline = _this$props.inline,
        items = _this$props.items,
        label = _this$props.label;
    var collapsed = this.state.collapsed;
    var collapseIcon = collapsed ? '+' : '-';
    var itemClass = cx('sui-CollapsibleComposed-item', {
      'sui-CollapsibleComposed-item--inline': inline
    });
    var togglerClass = cx('sui-CollapsibleComposed-toggler', {
      'sui-CollapsibleComposed-item--inline': inline
    });
    var itemsToToggle = !collapsed && hiddenItems || [];
    var totalItems = items.concat(itemsToToggle);
    var displayItems = totalItems.map(function (item, index) {
      return /*#__PURE__*/_jsx("div", {
        className: itemClass,
        children: item
      }, index);
    });
    return /*#__PURE__*/_jsxs("div", {
      className: "sui-CollapsibleComposed",
      children: [/*#__PURE__*/_jsx("div", {
        className: "sui-CollapsibleComposed-label",
        children: label
      }), /*#__PURE__*/_jsxs("div", {
        className: "sui-CollapsibleComposed-content",
        children: [displayItems, hiddenItems.length > 0 && /*#__PURE__*/_jsx("div", {
          className: togglerClass,
          onClick: function onClick() {
            return _this2._toggle();
          },
          children: collapseIcon
        })]
      })]
    });
  };

  return CollapsibleComposed;
}(Component);

CollapsibleComposed.displayName = 'CollapsibleComposed';
CollapsibleComposed.defaultProps = {
  collapsed: true,
  hiddenItems: [],
  inline: false,
  items: [],
  onToggle: function onToggle() {}
};
export default CollapsibleComposed;
